@@ -23,6 +23,6 @@ fn main() -> Result<()> {
         dbg!(n.data());
     }
 
-    print::print(&mut std::io::stdout(), &tree)?;
+    print::print(std::io::stdout(), &tree)?;
     Ok(())
 }
